var NAVTREEINDEX0 =
{
"AdvancedDataManagement.html":[33],
"AdvancedDataManagement.html#DataAccess":[33,2],
"AdvancedDataManagement.html#DataHandlesHelpers":[33,5],
"AdvancedDataManagement.html#DataManagementAllocation":[33,1],
"AdvancedDataManagement.html#DataPointers":[33,6],
"AdvancedDataManagement.html#DataPrefetch":[33,3],
"AdvancedDataManagement.html#DefiningANewDataFilter":[33,7],
"AdvancedDataManagement.html#DefiningANewDataInterface":[33,8],
"AdvancedDataManagement.html#DefiningANewDataInterface_allocation":[33,8,2],
"AdvancedDataManagement.html#DefiningANewDataInterface_copy":[33,8,3],
"AdvancedDataManagement.html#DefiningANewDataInterface_footprint":[33,8,1],
"AdvancedDataManagement.html#DefiningANewDataInterface_helpers":[33,8,6],
"AdvancedDataManagement.html#DefiningANewDataInterface_pack":[33,8,4],
"AdvancedDataManagement.html#DefiningANewDataInterface_pointers":[33,8,5],
"AdvancedDataManagement.html#DefiningANewDataInterface_registration":[33,8,0],
"AdvancedDataManagement.html#ManualPartitioning":[33,4],
"AdvancedDataManagement.html#SpecifyingATargetNode":[33,10],
"AdvancedDataManagement.html#TheMultiformatInterface":[33,9],
"AdvancedDataManagement.html#VariableSizeDataInterface":[33,0],
"AdvancedScheduling.html":[34],
"AdvancedScheduling.html#AutoHeteroprio":[34,2,1],
"AdvancedScheduling.html#Energy-basedScheduling":[34,0],
"AdvancedScheduling.html#LAHeteroprio":[34,2,0],
"AdvancedScheduling.html#MeasuringEnergyandPower":[34,0,0],
"AdvancedScheduling.html#StaticScheduling":[34,1],
"AdvancedScheduling.html#configuringHeteroprio":[34,2],
"AdvancedTasksInStarPU.html":[32],
"AdvancedTasksInStarPU.html#CombinedWorkers":[32,5,3],
"AdvancedTasksInStarPU.html#ConcurrentParallelTasks":[32,5,4],
"AdvancedTasksInStarPU.html#EnablingImplementationAccordingToCapabilities":[32,3],
"AdvancedTasksInStarPU.html#Fork-modeParallelTasks":[32,5,0],
"AdvancedTasksInStarPU.html#GettingTaskChildren":[32,4],
"AdvancedTasksInStarPU.html#ParallelTasks":[32,5],
"AdvancedTasksInStarPU.html#ParallelTasksPerformance":[32,5,2],
"AdvancedTasksInStarPU.html#SPMD-modeParallelTasks":[32,5,1],
"AdvancedTasksInStarPU.html#SequentialConsistency":[32,0,0],
"AdvancedTasksInStarPU.html#SynchronizationTasks":[32,6],
"AdvancedTasksInStarPU.html#TaskDependencies":[32,0],
"AdvancedTasksInStarPU.html#TasksAndTagsDependencies":[32,0,1],
"AdvancedTasksInStarPU.html#UsingMultipleImplementationsOfACodelet":[32,2],
"AdvancedTasksInStarPU.html#WaitingForTasks":[32,1],
"BasicExamples.html":[10],
"BasicExamples.html#DefiningACallback":[10,0,5],
"BasicExamples.html#DefiningACodelet":[10,0,1],
"BasicExamples.html#DefinitionOfTheCUDAKernel":[10,2,0],
"BasicExamples.html#DefinitionOfTheMainCode":[10,2,2],
"BasicExamples.html#DefinitionOfTheOpenCLKernel":[10,2,1],
"BasicExamples.html#ExecutionOfHelloWorld":[10,0,3],
"BasicExamples.html#ExecutionOfHybridVectorScaling":[10,2,3],
"BasicExamples.html#ExecutionOfVectorScaling":[10,1,1],
"BasicExamples.html#HelloWorldUsingStarPUAPI":[10,0],
"BasicExamples.html#PassingArgumentsToTheCodelet":[10,0,4],
"BasicExamples.html#RequiredHeaders":[10,0,0],
"BasicExamples.html#SourceCodeOfVectorScaling":[10,1,0],
"BasicExamples.html#SubmittingATask":[10,0,2],
"BasicExamples.html#VectorScalingOnAnHybridCPUGPUMachine":[10,2],
"BasicExamples.html#VectorScalingUsingStarPUAPI":[10,1],
"BasicExamples.html#WhereToExecuteACodelet":[10,0,6],
"BenchmarkingStarPU.html":[20],
"BenchmarkingStarPU.html#CholeskyFactorization":[20,3],
"BenchmarkingStarPU.html#DataTransferLatency":[20,1],
"BenchmarkingStarPU.html#LUFactorization":[20,4],
"BenchmarkingStarPU.html#MatrixMatrixMultiplication":[20,2],
"BenchmarkingStarPU.html#SimulatedBenchmarks":[20,5],
"BenchmarkingStarPU.html#TaskSizeOverhead":[20,0],
"BuildingAndInstallingStarPU.html":[4],
"BuildingAndInstallingStarPU.html#BuildingStarPU":[4,2,3],
"BuildingAndInstallingStarPU.html#ConfiguringStarPU":[4,2,2],
"BuildingAndInstallingStarPU.html#GettingSources":[4,2,1],
"BuildingAndInstallingStarPU.html#InstallingABinaryPackage":[4,0],
"BuildingAndInstallingStarPU.html#InstallingASourcePackage":[4,1],
"BuildingAndInstallingStarPU.html#InstallingFromSource":[4,2],
"BuildingAndInstallingStarPU.html#InstallingStarPU":[4,2,4],
"BuildingAndInstallingStarPU.html#OptionalDependencies":[4,2,0],
"BuildingAndInstallingStarPU.html#SpackInstallation":[4,1,0],
"BuildingAndInstallingStarPU.html#UsingModule":[4,1,1],
"CUDASupport.html":[38],
"CheckListWhenPerformanceAreNotThere.html":[24],
"CheckListWhenPerformanceAreNotThere.html#CUDA-specificOptimizations":[24,5],
"CheckListWhenPerformanceAreNotThere.html#CheckTaskSize":[24,0],
"CheckListWhenPerformanceAreNotThere.html#ConfigurationImprovePerformance":[24,1],
"CheckListWhenPerformanceAreNotThere.html#DataRelatedFeaturesToImprovePerformance":[24,2],
"CheckListWhenPerformanceAreNotThere.html#DetectionStuckConditions":[24,7],
"CheckListWhenPerformanceAreNotThere.html#HowToLimitMemoryPerNode":[24,8],
"CheckListWhenPerformanceAreNotThere.html#HowToReduceTheMemoryFootprintOfInternalDataStructures":[24,9],
"CheckListWhenPerformanceAreNotThere.html#HowtoReuseMemory":[24,10],
"CheckListWhenPerformanceAreNotThere.html#OpenCL-specificOptimizations":[24,6],
"CheckListWhenPerformanceAreNotThere.html#OverheadProfiling":[24,13],
"CheckListWhenPerformanceAreNotThere.html#PerformanceModelCalibration":[24,11],
"CheckListWhenPerformanceAreNotThere.html#Profiling":[24,12],
"CheckListWhenPerformanceAreNotThere.html#SchedulingRelatedFeaturesToImprovePerformance":[24,4],
"CheckListWhenPerformanceAreNotThere.html#TaskRelatedFeaturesToImprovePerformance":[24,3],
"CompilationConfiguration.html":[5],
"CompilationConfiguration.html#AdvancedConfiguration":[5,3],
"CompilationConfiguration.html#CommonConfiguration":[5,0],
"CompilationConfiguration.html#ConfiguringWorkers":[5,1],
"CompilationConfiguration.html#ExtensionConfiguration":[5,2],
"ConfigurationAndInitialization.html":[7],
"DataManagement.html":[13],
"DataManagement.html#AsynchronousPartitioning":[13,2],
"DataManagement.html#BCSRDataInterface":[13,0,6],
"DataManagement.html#BlockDataInterface":[13,0,3],
"DataManagement.html#COODataInterface":[13,0,8],
"DataManagement.html#CSRDataInterface":[13,0,7],
"DataManagement.html#ConcurrentDataAccess":[13,5],
"DataManagement.html#DataCommute":[13,3],
"DataManagement.html#DataInterface":[13,0],
"DataManagement.html#DataReduction":[13,4],
"DataManagement.html#MatrixDataInterface":[13,0,2],
"DataManagement.html#NdimDataInterface":[13,0,5],
"DataManagement.html#PartitioningData":[13,1],
"DataManagement.html#ScratchData":[13,6,1],
"DataManagement.html#TemporaryBuffers":[13,6],
"DataManagement.html#TemporaryData":[13,6,0],
"DataManagement.html#TensorDataInterface":[13,0,4],
"DataManagement.html#VariableDataInterface":[13,0,0],
"DataManagement.html#VectorDataInterface":[13,0,1],
"DebuggingTools.html":[52],
"DebuggingTools.html#DebuggingInGeneral":[52,0],
"DebuggingTools.html#UsingGdb":[52,1],
"DebuggingTools.html#UsingOtherDebugger":[52,2],
"DebuggingTools.html#UsingTheTemanejoTaskDebugger":[52,4],
"DebuggingTools.html#WatchdogSupport":[52,3],
"DocOrganization.html":[1],
"ExamplesInStarPUSources.html":[15],
"ExecutionConfigurationThroughEnvironmentVariables.html":[6],
"ExecutionConfigurationThroughEnvironmentVariables.html#Basic":[6,0,0],
"ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringAutoHeteroprio":[6,2,1],
"ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringHeteroprio":[6,2],
"ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringLaHeteroprio":[6,2,0],
"ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringTheHypervisor":[6,5],
"ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringTheSchedulingEngine":[6,1],
"ExecutionConfigurationThroughEnvironmentVariables.html#EnvConfiguringWorkers":[6,0],
"ExecutionConfigurationThroughEnvironmentVariables.html#Extensions":[6,3],
"ExecutionConfigurationThroughEnvironmentVariables.html#MiscellaneousAndDebug":[6,4],
"ExecutionConfigurationThroughEnvironmentVariables.html#cpuWorkers":[6,0,1],
"ExecutionConfigurationThroughEnvironmentVariables.html#cudaWorkers":[6,0,2],
"ExecutionConfigurationThroughEnvironmentVariables.html#hipWorkers":[6,0,7],
"ExecutionConfigurationThroughEnvironmentVariables.html#maxfpgaWorkers":[6,0,4],
"ExecutionConfigurationThroughEnvironmentVariables.html#mpiConf":[6,0,8],
"ExecutionConfigurationThroughEnvironmentVariables.html#mpimsWorkers":[6,0,5],
"ExecutionConfigurationThroughEnvironmentVariables.html#openclWorkers":[6,0,3],
"ExecutionConfigurationThroughEnvironmentVariables.html#tcpipmsWorkers":[6,0,6],
"FFTSupport.html":[46],
"FFTSupport.html#FFTCompilation":[46,0],
"FaultTolerance.html":[45],
"FaultTolerance.html#FaultTolerance_Introduction":[45,0],
"FaultTolerance.html#TaskRetry":[45,1],
"Files.html":[55],
"FrequentlyAskedQuestions.html":[25],
"FrequentlyAskedQuestions.html#CUDACopyError":[25,12],
"FrequentlyAskedQuestions.html#CUDADrivers":[25,9],
"FrequentlyAskedQuestions.html#GPUEatingCores":[25,8],
"FrequentlyAskedQuestions.html#HIPDrivers":[25,10],
"FrequentlyAskedQuestions.html#HardwareTopology":[25,1],
"FrequentlyAskedQuestions.html#HowToInitializeAComputationLibraryOnceForEachWorker":[25,0],
"FrequentlyAskedQuestions.html#IncorrectPerformanceModelFile":[25,13],
"FrequentlyAskedQuestions.html#InteroperabilityHWLOC":[25,1,0],
"FrequentlyAskedQuestions.html#On-GPURendering":[25,3],
"FrequentlyAskedQuestions.html#OpenCLDrivers":[25,11],
"FrequentlyAskedQuestions.html#PauseResume":[25,7],
"FrequentlyAskedQuestions.html#StarPUEatsCPUs":[25,6],
"FrequentlyAskedQuestions.html#ThreadBindingOnNetBSD":[25,5],
"FrequentlyAskedQuestions.html#TopologyBus":[25,1,3],
"FrequentlyAskedQuestions.html#TopologyMemory":[25,1,1],
"FrequentlyAskedQuestions.html#TopologyWorkers":[25,1,2],
"FrequentlyAskedQuestions.html#UsingStarPUWithMKL":[25,4],
"FrequentlyAskedQuestions.html#UsingTheDriverAPI":[25,2],
"FullSourceCodeVectorScal.html":[11],
"FullSourceCodeVectorScal.html#CPUKernel":[11,1],
"FullSourceCodeVectorScal.html#CUDAKernel":[11,2],
"FullSourceCodeVectorScal.html#InvokingtheKernel":[11,3,0],
"FullSourceCodeVectorScal.html#MainApplication":[11,0],
"FullSourceCodeVectorScal.html#OpenCLKernel":[11,3],
"FullSourceCodeVectorScal.html#SourceoftheKernel":[11,3,1],
"GNUFreeDocumentationLicense.html":[54],
"GNUFreeDocumentationLicense.html#ADDENDUM":[54,0],
"Glossary.html":[2],
"Helpers.html":[53],
"HierarchicalDAGS.html":[48],
"HierarchicalDAGS.html#BubblesBubbleVersion":[48,0,1],
"HierarchicalDAGS.html#BubblesExamples":[48,0],
"HierarchicalDAGS.html#BubblesInitialVersion":[48,0,0],
"HowToDefineANewSchedulingPolicy.html":[37],
"HowToDefineANewSchedulingPolicy.html#BuildAModularizedScheduler":[37,3,1],
"HowToDefineANewSchedulingPolicy.html#DebuggingScheduling":[37,6],
"HowToDefineANewSchedulingPolicy.html#DefiningANewBasicSchedulingPolicy":[37,2],
"HowToDefineANewSchedulingPolicy.html#DefiningANewModularSchedulingPolicy":[37,3],
"HowToDefineANewSchedulingPolicy.html#DetailedProgressionAndValidationRules":[37,3,3,2],
"HowToDefineANewSchedulingPolicy.html#GenericSchedulingComponent":[37,3,3,0],
"HowToDefineANewSchedulingPolicy.html#GraphScheduling":[37,5],
"HowToDefineANewSchedulingPolicy.html#ImplementAModularizedScheduler":[37,3,1,3],
"HowToDefineANewSchedulingPolicy.html#InstantiationRedefineInterface":[37,3,3,1],
"HowToDefineANewSchedulingPolicy.html#Interface":[37,3,0],
"HowToDefineANewSchedulingPolicy.html#ModularizedSchedulerLocking":[37,3,1,2],
"HowToDefineANewSchedulingPolicy.html#ModularizedSchedulersAndParallelTasks":[37,3,2],
"HowToDefineANewSchedulingPolicy.html#NewSchedulingPolicy_Introduction":[37,0],
"HowToDefineANewSchedulingPolicy.html#PreImplementedComponents":[37,3,1,0],
"HowToDefineANewSchedulingPolicy.html#ProgressionAndValidationRules":[37,3,1,1],
"HowToDefineANewSchedulingPolicy.html#SchedulingHelpers":[37,1],
"HowToDefineANewSchedulingPolicy.html#UsingaNewSchedulingPolicy":[37,4],
"HowToDefineANewSchedulingPolicy.html#WriteASchedulingComponent":[37,3,3],
"InteroperabilitySupport.html":[50],
"InteroperabilitySupport.html#Build":[50,0,0],
"InteroperabilitySupport.html#DefCTX":[50,0,2],
"InteroperabilitySupport.html#InitExit":[50,0,1],
"InteroperabilitySupport.html#ResourceManagement":[50,0],
"InteroperabilitySupport.html#TmpCTXS":[50,0,3],
"IntroApplications.html":[16],
"IntroBasics.html":[8],
"IntroExtensions.html":[31],
"IntroFAQ.html":[23],
"IntroInstallation.html":[3],
"IntroLanguage.html":[26],
"IntroPerformances.html":[19],
"MPISupport.html":[42],
"MPISupport.html#ExampleDocumentation":[42,1],
"MPISupport.html#ExchangingUserDefinedDataInterface":[42,6],
"MPISupport.html#MPIBuild":[42,0],
"MPISupport.html#MPICache":[42,14],
"MPISupport.html#MPICheckpoint":[42,22],
"MPISupport.html#MPICollective":[42,16],
"MPISupport.html#MPIDebug":[42,18],
"MPISupport.html#MPIDriver":[42,17],
"MPISupport.html#MPIExamples":[42,19],
"MPISupport.html#MPIInitialization":[42,4],
"MPISupport.html#MPIInsertPruning":[42,9],
"MPISupport.html#MPIInsertTaskUtility":[42,7],
"MPISupport.html#MPIMasterSlave":[42,21],
"MPISupport.html#MPIMigration":[42,15],
"MPISupport.html#MPIMpiRedux":[42,12],
"MPISupport.html#MPIPerNodeData":[42,11],
"MPISupport.html#MPIPriorities":[42,13],
"MPISupport.html#MPITaskUtility":[42,8],
"MPISupport.html#MPITemporaryData":[42,10],
"MPISupport.html#Nmad":[42,20],
"MPISupport.html#NotUsingMPISupport":[42,2],
"MPISupport.html#PointToPointCommunication":[42,5],
"MPISupport.html#SimpleExample":[42,3],
"MaxFPGASupport.html":[40],
"MaxFPGASupport.html#Introduction":[40,0],
"MaxFPGASupport.html#MaxFPGAConfiguration":[40,1,2],
"MaxFPGASupport.html#MaxFPGADataTransfers":[40,1,1],
"MaxFPGASupport.html#MaxFPGAExample":[40,1,0],
"MaxFPGASupport.html#MaxFPGALaunchingprograms":[40,1,3],
"MaxFPGASupport.html#PortingApplicationsToMaxFPGA":[40,1],
"NativeFortranSupport.html":[27],
"NativeFortranSupport.html#NFAPIMIX":[27,5,1],
"NativeFortranSupport.html#NFAppCompile":[27,0,3],
"NativeFortranSupport.html#NFConfiguration":[27,0,1]
};
